@@ -1,5 +1,5 @@
 from math import pi as _pi
-from ._if_not_int_or_float_raise import _if_not_int_or_float_raise
+from ._if_not_valid_raise import _if_not_int_or_float_raise, _if_negative_raise
 
 
 def circle_area(r):
@@ -20,7 +20,8 @@ def circle_area(r):
     Raises
     ------
     ValueError
-        If r is not an integer or float
+        If r is not an integer or float.
+        If r is negative.
 
     Examples
     --------
@@ -29,4 +30,5 @@ def circle_area(r):
 
     """
     _if_not_int_or_float_raise(r)
+    _if_negative_raise(r)
     return _pi * (r**2)
