@@ -1,4 +1,4 @@
-from ._if_not_int_or_float_raise import _if_not_int_or_float_raise
+from ._if_not_valid_raise import _if_not_int_or_float_raise, _if_negative_raise
 
 def trapezium_area(c, b, h):
     """
